@@ -1,7 +1,7 @@
 package Bencher::Scenario::Example;
 
-our $DATE = '2015-10-08'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-10-09'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 our $scenario = {
     participants => [
@@ -29,7 +29,11 @@ Bencher::Scenario::Example - An example scenario
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::Example (from Perl distribution Bencher), released on 2015-10-08.
+This document describes version 0.02 of Bencher::Scenario::Example (from Perl distribution Bencher), released on 2015-10-09.
+
+=head1 SYNOPSIS
+
+ % bencher -m Example [other options]...
 
 =head1 HOMEPAGE
 
